@@ -1,7 +1,6 @@
 
 import pycares
 import selectors
-import socket
 
 
 class DNSResolver(object):
@@ -44,9 +43,6 @@ class DNSResolver(object):
     def query(self, query_type, name, cb):
         self._channel.query(query_type, name, cb)
 
-    def gethostbyname(self, name, cb):
-        self._channel.gethostbyname(name, socket.AF_INET, cb)
-
     def close(self):
         """Close the resolver and cleanup resources."""
         for fd in list(self._fd_map):
@@ -58,18 +54,23 @@ class DNSResolver(object):
 
 if __name__ == '__main__':
     def query_cb(result, error):
-        print(result)
-        print(error)
-    def gethostbyname_cb(result, error):
-        print(result)
-        print(error)
+        if error:
+            print("Error: {}".format(error))
+        else:
+            print("DNS Result:")
+            print("  Answer: {} records".format(len(result.answer)))
+            for record in result.answer:
+                print("    - {} (TTL: {}s): {}".format(record.name, record.ttl, record.data))
+            if result.authority:
+                print("  Authority: {} records".format(len(result.authority)))
+            if result.additional:
+                print("  Additional: {} records".format(len(result.additional)))
     resolver = DNSResolver()
     try:
         resolver.query('google.com', pycares.QUERY_TYPE_A, query_cb)
         resolver.query('google.com', pycares.QUERY_TYPE_AAAA, query_cb)
         resolver.query('facebook.com', pycares.QUERY_TYPE_A, query_cb)
         resolver.query('sip2sip.info', pycares.QUERY_TYPE_SOA, query_cb)
-        resolver.gethostbyname('apple.com', gethostbyname_cb)
         resolver.wait_channel()
     finally:
         resolver.close()
