@@ -32,6 +32,10 @@ def parse_name_idna2008(name: str) -> str:
     for part in parts:
         if part.isascii():
             r.append(part.encode('ascii'))
+        elif len(part) > 253:
+            raise RuntimeError(
+                f"domains can only be less than 253 characters in length not {len(name)}"
+            )
         else:
             r.append(idna2008.encode(part))
     return b'.'.join(r)
