@@ -5,8 +5,14 @@ import sys
 
 import pycares
 
+
+def dummy(*args):
+    pass
+
+
 # Create a channel
-channel = pycares.Channel()
+# TODO: using event thread seems to crash on Windows 11 ARM.
+channel = pycares.Channel(sock_state_cb=dummy)
 
 
 # Start a query to ensure pending handles
@@ -14,7 +20,7 @@ def callback(result, error):
     pass
 
 
-channel.query("example.com", pycares.QUERY_TYPE_A, callback)
+channel.query("example.com", pycares.QUERY_TYPE_A, callback=callback)
 
 # Exit immediately - the channel will be garbage collected during interpreter shutdown
 # This should not raise PythonFinalizationError
